@@ -102,10 +102,24 @@ space-separated token."
 
 (defun org-social-parser--get-my-profile ()
   "Get the current user's profile from their Org-social file."
-  (let ((feed nil))
-    (when (file-exists-p org-social-file)
+  ;; Ensure vfile is downloaded if needed
+  (when (and (fboundp 'org-social-file--ensure-vfile-downloaded)
+             (fboundp 'org-social-file--is-vfile-p)
+             (org-social-file--is-vfile-p org-social-file))
+    (org-social-file--ensure-vfile-downloaded))
+
+  (let ((feed nil)
+        (target-file (if (and (fboundp 'org-social-file--is-vfile-p)
+                              (org-social-file--is-vfile-p org-social-file)
+                              (fboundp 'org-social-file--get-local-file-path))
+                         (org-social-file--get-local-file-path org-social-file)
+                       org-social-file)))
+    (when (file-exists-p target-file)
       (with-temp-buffer
-        (insert-file-contents org-social-file)
+        (insert-file-contents target-file)
+        ;; Process migrations if the function exists
+        (when (fboundp 'org-social-file--process-migrations)
+          (org-social-file--process-migrations))
         (setq feed (buffer-string)))
       (let* ((follows (org-social-parser--get-value feed "FOLLOW"))
              (follows-list (if (listp follows) follows (list follows)))
@@ -117,6 +131,10 @@ space-separated token."
          (cons 'title (org-social-parser--get-value feed "TITLE"))
          (cons 'description (org-social-parser--get-value feed "DESCRIPTION"))
          (cons 'avatar (org-social-parser--get-value feed "AVATAR"))
+         (cons 'location (org-social-parser--get-value feed "LOCATION"))
+         (cons 'birthday (org-social-parser--get-value feed "BIRTHDAY"))
+         (cons 'language (org-social-parser--get-value feed "LANGUAGE"))
+         (cons 'pinned (org-social-parser--get-value feed "PINNED"))
          (cons 'url (or org-social-my-public-url org-social-file))  ; Use public URL if available, fallback to file path
          (cons 'follow (mapcar #'org-social-parser--parse-follow (delq nil follows-list)))
          (cons 'group (mapcar #'org-social-parser--parse-group (delq nil groups-list)))
@@ -126,7 +144,8 @@ space-separated token."
   "Extract a property value from TEXT according to Org Social specification.
 PROP-NAME should be the property name without colons.
 Validates format according to specification - ignores invalid values."
-  (when (string-match (format ":%s:\\s-*\\([^\n]+\\)" (regexp-quote prop-name)) text)
+  (when (and (stringp text)
+             (string-match (format ":%s:\\s-*\\([^\n]+\\)" (regexp-quote prop-name)) text))
     (let ((value (string-trim (match-string 1 text))))
       ;; Enhanced validation according to Org Social specification
       (when (and (not (string-empty-p value))
@@ -145,11 +164,19 @@ Validates format according to specification - ignores invalid values."
         (insert feed)
         (goto-char (point-min))
         (when (re-search-forward "^\\* Posts" nil t)
-          (while (re-search-forward "^\\*\\*[^*]" nil t)
+          (while (re-search-forward "^\\*\\*\\($\\|[^*]\\)" nil t)
             (let ((post-start (point))
-                  post-end id text date properties-text)
+                  post-end id id-from-header id-from-properties text date properties-text)
+              ;; Extract ID from header (after **)
+              (beginning-of-line)
+              (when (looking-at "^\\*\\*\\s-+\\([0-9]\\{4\\}-[0-9]\\{2\\}-[0-9]\\{2\\}T[0-9]\\{2\\}:[0-9]\\{2\\}:[0-9]\\{2\\}[+-][0-9]\\{2\\}\\(:[0-9]\\{2\\}\\|[0-9]\\{2\\}\\)\\)")
+                (setq id-from-header (match-string 1)))
+              (end-of-line)
+              (forward-char)
+              (setq post-start (point))
+
               ;; Find the end of this post (next ** or end of buffer)
-              (if (re-search-forward "^\\*\\*[^*]" nil t)
+              (if (re-search-forward "^\\*\\*\\($\\|[^*]\\)" nil t)
                   (progn
                     (backward-char)  ; Move back to the line with **
                     (beginning-of-line)
@@ -164,8 +191,12 @@ Validates format according to specification - ignores invalid values."
                   (when (re-search-forward ":END:" post-end t)
                     (setq properties-text (buffer-substring-no-properties prop-start (point))))))
 
-              ;; Extract basic required properties
-              (setq id (org-social-parser--extract-property properties-text "ID"))
+              ;; Extract ID from properties
+              (setq id-from-properties (org-social-parser--extract-property properties-text "ID"))
+
+              ;; Use ID from header if present, otherwise use ID from properties
+              ;; According to Org Social spec v1.6: if both are present, header takes priority
+              (setq id (or id-from-header id-from-properties))
               (when id (setq date (safe-date-to-time id)))
 
               ;; Extract text content (after :END:)
@@ -187,7 +218,8 @@ Validates format according to specification - ignores invalid values."
                   (setq text (string-trim (string-join (reverse content-lines) "\n")))))
 
               ;; Add post if we have required data
-              (when (and id text date properties-text)
+              ;; Properties are optional, so we only require id, text, and date
+              (when (and id text date)
                 (let ((post-data (list
                                   (cons 'id (gensym))
                                   (cons 'timestamp id)
@@ -195,9 +227,9 @@ Validates format according to specification - ignores invalid values."
                                   (cons 'text text))))
 
                   ;; Extract only official properties according to Org Social specification
-                  ;; Official properties: LANG, TAGS, CLIENT, REPLY_TO, POLL_END, POLL_OPTION, GROUP, MOOD, INCLUDE
+                  ;; Official properties: LANG, TAGS, CLIENT, REPLY_TO, POLL_END, POLL_OPTION, GROUP, MOOD, INCLUDE, VISIBILITY
                   (dolist (prop '("LANG" "TAGS" "CLIENT" "REPLY_TO" "POLL_END"
-                                  "POLL_OPTION" "GROUP" "MOOD" "INCLUDE"))
+                                  "POLL_OPTION" "GROUP" "MOOD" "INCLUDE" "VISIBILITY"))
                     (let ((value (org-social-parser--extract-property properties-text prop)))
                       (when value
                         (setq post-data (cons (cons (intern (downcase prop)) value) post-data)))))
@@ -238,6 +270,10 @@ Returns t if valid, nil if invalid (should be ignored)."
    ((member prop-name '("CLIENT" "POLL_OPTION" "MOOD"))
     (and (< (length value) 200)  ; Reasonable length limit
          (null (string-match-p "[\n\r]" value))))  ; No newlines
+   ;; VISIBILITY must be either "public" or "mention"
+   ((string= prop-name "VISIBILITY")
+    (or (string= value "public")
+        (string= value "mention")))
    ;; Default: accept other properties
    (t t)))
 
@@ -248,5 +284,17 @@ Accepts formats: ####-##-##T##:##:##+##:## or ####-##-##T##:##:##-####"
     (or (string-match-p "^[0-9]\{4\}-[0-9]\{2\}-[0-9]\{2\}T[0-9]\{2\}:[0-9]\{2\}:[0-9]\{2\}[+-][0-9]\{2\}:[0-9]\{2\}$" id)
         (string-match-p "^[0-9]\{4\}-[0-9]\{2\}-[0-9]\{2\}T[0-9]\{2\}:[0-9]\{2\}:[0-9]\{2\}[+-][0-9]\{4\}$" id))))
 
+(defun org-social-parser--extract-mentioned-urls (text)
+  "Extract all org-social URLs mentioned in TEXT.
+Returns a list of URLs from [[org-social:URL][name]] links."
+  (when (stringp text)
+    (let ((urls '())
+          (pos 0))
+      (while (string-match "\\[\\[org-social:\\([^]]+\\)\\]\\[\\([^]]+\\)\\]\\]" text pos)
+        (let ((url (match-string 1 text)))
+          (push url urls)
+          (setq pos (match-end 0))))
+      (reverse urls))))
+
 (provide 'org-social-parser)
 ;;; org-social-parser.el ends here
